Hasegawa-Wakatani
=================

The Hasegawa-Wakatani equations, implemented using Poisson brackets `[]`:

    ddt(n) = -[phi, n] + alpha*(phi - n) - kappa*DDZ(phi)
    ddt(vorticity) = -[phi, vorticity] + alpha*(phi - n)

where `alpha`, `kappa` are constants
